package com.aitrainer.api.controller

import com.aitrainer.api.model.CustomerMembership
import com.aitrainer.api.repository.CustomerMembershipRepository
import org.slf4j.LoggerFactory
import org.springframework.http.ResponseEntity
import org.springframework.security.access.annotation.Secured
import org.springframework.web.bind.annotation.*
import javax.validation.Valid

@RestController
@RequestMapping("/api")
class CustomerMembershipController(private val customerMembershipRepository: CustomerMembershipRepository) {
    private val logger = LoggerFactory.getLogger(javaClass)

    @PostMapping("/customer_membership")
    fun createNewCustomerMembership(@Valid @RequestBody customerMembership: CustomerMembership): ResponseEntity<CustomerMembership> {
        logger.info("Create customer membership: $customerMembership")
        return ResponseEntity.ok().body(customerMembershipRepository.save(customerMembership))
    }

    @Secured
    @PostMapping("customer_membership/update/{id}")
    fun updateCustomerMembership(@PathVariable(value = "id") membershipId: Long,
                               @Valid @RequestBody membershipToUpdate: CustomerMembership): ResponseEntity<CustomerMembership> {
        val customerMembership = customerMembershipRepository.findById(membershipId).orElse(null)
            ?: return ResponseEntity.notFound().build()

        val updatedCustomerMembership = customerMembership.copy(
            trainingPlanId = membershipToUpdate.trainingPlanId,
            days = membershipToUpdate.days,

        )
        return ResponseEntity.ok().body(customerMembershipRepository.save(updatedCustomerMembership))
    }

    @GetMapping("/customer_membership/{customer_id}")
    fun getAllByCustomerId(@PathVariable(value = "customer_id") customerId: Long): ResponseEntity<List<CustomerMembership>> {

        val membershipList: List<CustomerMembership>  = customerMembershipRepository.findAllByCustomerId(customerId)
        logger.info("Get all customer_membership by by customerId")

        return if(membershipList.isNotEmpty())
            ResponseEntity.ok().body(membershipList) else
            ResponseEntity.notFound().build()
    }
}