package com.aitrainer.api.test

import com.aitrainer.api.controller.CustomerMembershipController
import com.aitrainer.api.model.CustomerMembership
import com.aitrainer.api.repository.CustomerMembershipRepository
import org.junit.jupiter.api.Test
import org.junit.jupiter.api.TestInstance
import org.springframework.beans.factory.annotation.Autowired
import org.springframework.boot.test.context.SpringBootTest
import org.springframework.http.HttpStatus
import kotlin.test.assertEquals
import kotlin.test.assertTrue

@SpringBootTest
@TestInstance(TestInstance.Lifecycle.PER_CLASS)
class CustomerMembershipTest {

    private var insertedId: Long = 0
    private var deleteInsert: Boolean = true

    @Autowired
    private lateinit var customerMembershipRepository: CustomerMembershipRepository


    @Test
    fun testCustomerMembershipByCustomerId() {
        val controller = CustomerMembershipController(customerMembershipRepository )
        val response = controller.getAllByCustomerId(90)

        val properties = response.body

        assertTrue(properties is List)
        assertTrue(properties.isNotEmpty())
        assertEquals(properties.size, 2)
        assertEquals(properties[0].trainingPlanId, 99)
        assertEquals(properties[0].days, "22|23")
    }

    @Test
    fun testInsert() {
        val customerMembership = CustomerMembership(
            customerId = 90,
            membershipId = 3,
            startDate = "2023-01-30",
            trainingPlanId = 103
        )

        val controller = CustomerMembershipController(customerMembershipRepository)
        val response = controller.createNewCustomerMembership(customerMembership)

        val newCustomerMembership = response.body

        assertTrue(newCustomerMembership is CustomerMembership)
        assertEquals(newCustomerMembership.trainingPlanId, 103)

        if ( this.deleteInsert ) {
            customerMembershipRepository.delete(customerMembership)
        } else {
            this.insertedId = newCustomerMembership.id
        }

    }

    @Test
    fun testUpdate() {
        this.deleteInsert = false
        this.testInsert()
        var customerMembership = CustomerMembership(
            customerId = 90,
            startDate = "2020-11-10",
            trainingPlanId = 99
        )
        val controller = CustomerMembershipController(customerMembershipRepository)

        var response = controller.updateCustomerMembership(this.insertedId, customerMembership)

        assertTrue(response.body is CustomerMembership)
        val updated = response.body
        assertEquals(updated!!.trainingPlanId, 99)
        assertEquals(updated.startDate, "2023-01-30 00:00:00" )
        customerMembershipRepository.delete(updated)

        //notFound
        customerMembership = CustomerMembership(
            id = 10000,
            startDate = "2021-02-15",
            trainingPlanId = 83
        )
        response = controller.updateCustomerMembership(customerMembership.id, customerMembership)
        assertEquals(response.statusCode, HttpStatus.NOT_FOUND)



    }

}